==> AdvancedContent-0.8.tgz: AdvancedContent/lang/de_DE.php <==
<?php
$lang['AdvancedContent'] = 'Erweiterter Inhalt';
$lang['advancedcontent_tabname'] = 'Erweiterte Optionen';
$lang['installed'] = 'Modul AdvancedContent %s wurde installiert';
$lang['uninstalled'] = 'Modul AdvancedContent %s wurde deinstalliert';
$lang['upgraded'] = 'Modul AdvancedContent auf Version %s aktualisiert';
$lang['postinstall'] = 'Modul AdvancedContent %s wurde installiert.';
$lang['postuninstall'] = 'Modul AdvancedContent %s wurde deinstalliert.';
$lang['confirmuninstall'] = '%sWollen Sie das Modul AdvancedContent wirklich deinstallieren?';
$lang['warninguninstall'] = "WARNUNG! Sie haben in den Moduleinstellungen keine Aktion beim Deinstallieren gewählt! Stellen Sie sicher, dass alle Seiten vom Typ 'Erweiterter Inhalt' zurück auf den Standard-Inhaltstypen geändert oder gelöscht werden bevor Sie das Modul entfernen! Anderenfalls funktioniert Ihre CMS Installation nicht mehr! ";
$lang['warninguninstall1'] = "WARNUNG! Damit werden alle Seiten vom Typ 'Erweiterter Inhalt' gelöscht! ";
$lang['warninguninstall2'] = "HINWEIS: Alle Seiten vom Typ 'Erweiterter Inhalt' werden wieder auf den Standard-Inhaltstypen gesetzt! ";
$lang['warninguninstall3'] = "WARNUNG! Alle Seiten vom Typ 'Erweiterter Inhalt' werden wieder auf den Standard-Inhaltstypen gesetzt und alle zusätzichen Inhaltsblöcke werden gelöscht! ";
$lang['notice_duplicatecontent'] = '<em><strong>Hinweis:</strong> Dieser Block wird mehrfach im Template verwendet. Sie sehen hier nur den ersten Block.</em>';
$lang['error_basicattrib'] = "<em><strong>Hinweis:</strong> Der Basis-Inhalts-Eigenschafts-Name '%s' kann nicht als Wert f&uuml;r den Parameter 'block' verwendet werden. <br />Dieser Block ist inaktiv. Nur der erste Block wird angezeigt. Pr&uuml;fen Sie Ihr Seiten-Template und w&auml;hlen Sie f&uuml;r den Parameter 'block' einen anderen Wert.</em>";
$lang['error_expiredate'] = 'Das Enddatum muss hinter dem Startdatum liegen.';
$lang['youareintext'] = 'Aktuelles Verzeichnis';
$lang['dimensions'] = 'Bildgr&ouml;&szlig;e';
$lang['size'] = 'Dateigr&ouml;&szlig;e';
$lang['inherit_from_parent'] = 'Vom &uuml;bergeordneten Element &uuml;bernehmen';
$lang['none'] = 'nichts';
$lang['invalid'] = 'ung&uuml;ltig';
$lang['invalid_blocktype'] = "<em><strong>Notice:</strong> Ung&uuml;ltiger Wert '%s' des Parameters block_type im Block '%s'.<br />Bitte pr&uuml;fen Sie Ihr Seiten-Template.</em>";
$lang['error_insufficient_blockparams'] = "<em><strong>Fehler:</strong> Unzureichende parameter. <br />Fehlender param '%s' f&uuml;r block '%s'. &Uuml;berpr&uuml;fen Sie Ihr Seiten-Template.</em>";
$lang['yes'] = 'Ja';
$lang['no'] = 'Nein';
$lang['frontendaccess'] = 'Frontend-Zugriff';
$lang['redirectpage'] = 'Seite auf die umgeleitet werden soll, wenn der Zugriff nicht erlaubt ist';
$lang['showloginform'] = 'Anmelde-Formular anzeigen';
$lang['registeredusers'] = 'Nur f&uuml;r registrierte Nutzer';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Ablaufdatum verwenden';
$lang['startdate'] = 'Startdatum';
$lang['enddate'] = 'Enddatum';
$lang['blockcontent'] = 'Block-Inhalt';
$lang['setpageinactive'] = 'Seite auf inaktiv setzen';
$lang['deletepage'] = 'Seite l&ouml;schen';
$lang['uninstallaction'] = 'Aktion beim Deinstallieren';
$lang['setcontent1'] = 'Alle Seiten auf Typ "Inhalt" setzen';
$lang['setcontent2'] = 'Alle Seiten auf Typ "Inhalt" setzen und AdvancedContent-Bl&ouml;cke l&ouml;schen';
$lang['prefsupdated'] = 'Einstellungen aktualisiert';
$lang['success'] = 'OK';
$lang['error'] = 'Fehler';
$lang['deletepages'] = 'Alle Seiten vom Typ "Erweiterter Inhalt" l&ouml;schen';
$lang['importpages'] = "Alle Seiten vom Typ '%s' auf Typ '%s' setzen.";
$lang['confirmimport'] = 'Wollen Sie wirklich den Inhalts-Typ aller Inhaltsseiten &auml;ndern?';
$lang['toggle_message'] = 'Diese Nachricht verbergen';
$lang['contentsettings'] = 'Standard-Einstellungen f&uuml;r den Tab "Erweiterte Optionen"';
$lang['redirectparams'] = 'URL-Parameter, die bei Umleitung angehangen werden sollen';
$lang['evaluatesmarty'] = 'Smarty verwenden, um die Parameter zu verarbeiten';
$lang['error_loading_module'] = "<em><strong>Fehler:</strong> Modul '%s' konnte nicht geladen werden. (angegeben f&uuml;r Block '%s' im Seiten-Template.)</em>";
$lang['error_contentblock_support'] = "<em><strong>Fehler:</strong> Modul '%s' unterst&uuml;tzt keine Inhaltsbl&ouml;cke. (angegeben f&uuml; block '%s' im Seiten-Template.)</em>";
$lang['success_importpages'] = "Alle Seiten des Typs '%s' erfolgreich ge&auml;ndert in '%s'";
$lang['show_advancedcontent_options'] = "Zeige Tab 'Erweiterte Optionen'";
$lang['display_settings'] = '%s Einstellungen anzeigen';
$lang['save_collapse_status'] = 'Speichere Sichtbarkeit von %s';
$lang['content_blocks'] = 'Inhaltsbl&ouml;cke';
$lang['block_message'] = 'Block-Mitteilungen';
$lang['block_groups'] = 'Blockgruppe';
$lang['collapse_default'] = 'Blende %s aus';
$lang['per_page'] = 'pro Seite';
$lang['per_template'] = 'pro Template';
$lang['both1'] = 'Template ODER Seite ';
$lang['both2'] = 'Template UND Seite';
$lang['content'] = 'Inhalt';
$lang['content2'] = 'Erweiterter Inhalt';
$lang['prefs'] = 'Einstellungen';
$lang['multi_input'] = 'Multi Inputs';
$lang['multi_input_tpl'] = 'Multi Input Templates';
$lang['add_multi_input'] = 'Neues multi input hinzug&uuml;gen';
$lang['add_multi_input_tpl'] = 'Neues multi input template hinzuf&uuml;gen';
$lang['input_id'] = 'Eingabe-ID';
$lang['input_fields'] = 'Eingabefelder';
$lang['tpl_name'] = 'Template Name';
$lang['error_template'] = 'Template ist ein Pflichtfeld und darf nicht leer sein ';
$lang['error_input_fields'] = 'Eingabefelder ist ein Pflichtfeld und darf nicht leer sein.';
$lang['error_input_id'] = 'Keine Eingabe-ID angegeben oder Eingabe-ID ist bereits vorhanden.';
$lang['error_input_id_exists'] = 'Eingabe-ID wird bereits verwendet. W&auml;hlen Sie eine andere. (Muss eindeutig sein)';
$lang['multi_input_added'] = 'Multi Input hinzugef&uuml;gt.';
$lang['multi_input_deleted'] = 'Multi Input gel&ouml;scht.';
$lang['multi_input_updated'] = 'Multi Input aktualisiert.';
$lang['multi_input_tpl_added'] = 'Multi Input template hinzugef&uuml;gt.';
$lang['multi_input_tpl_updated'] = 'Multi Input template aktualisiert.';
$lang['multi_input_tpl_deleted'] = 'Multi Input template gel&ouml;scht.';
$lang['delete_selected'] = 'Ausgew&auml;hlte Elemente l&ouml;schen';
$lang['confirm_delete'] = 'Wollen Sie wirklich, dieses Element l&ouml;schen?';
$lang['confirm_delete_selected'] = 'Wollen Sie wirklich, die ausgew&auml;hlten Elemente l&ouml;schen?';
$lang['hide_content'] = 'Keine (nur Inhalt verbergen)';
$lang['hide_menu_item'] = 'Seite im Men&uuml; verbergen';
$lang['loggedout'] = 'wenn ausgeloggt';
$lang['loggedin'] = 'wenn eingeloggt';
$lang['aftercurrdate'] = 'nach dem aktuellen Datum';
$lang['afterstartdate'] = 'nach dem Startdatum';
$lang['minutes'] = 'Minuten';
$lang['hours'] = 'Stunden';
$lang['days'] = 'Tage';
$lang['weeks'] = 'Wochen';
$lang['months'] = 'Monate';
$lang['years'] = 'Jahre';
$lang['help_tpl_vars'] = '<p><strong>Template-Variablen:</strong></p>
<p><pre><code>{$inputs}</code></pre> ist ein Array welches alle Input-Elemente des MultiInput Blocks enth&auml;t.<br />
Jedes Input-Element ist wiederum ein Array welches alle Parameter enth&auml;lt. <br />
(Siehe Modulhilfe)<br />
Zus&auml;tzlicher Parameter ist "input". Dieser gibt das Inputfeld aus.<br />
Um auf die Paramater zuzugreifen wird der Punkt-Syntax verwendet.<br />
Beispiel:</p>
<pre><code>{foreach from=$inputs item=elm}
	{$elm.label}:&nbsp;{$elm.input}<br />
{/foreach}</code></pre>';
?>

==> AdvancedContent-0.9.2.tgz: AdvancedContent/lang/de_DE.php <==
<?php
$lang['AdvancedContent'] = 'Erweiterter Inhalt';
$lang['admindescription'] = 'Erweiterter Inhaltstyp mit benutzerdefinierten Feldern beim Bearbeiten einer Seite und einigen zus&auml;tzlichen Funktionen';
$lang['advancedcontent_tabname'] = 'Erweiterte Optionen';
$lang['installed'] = 'Modul AdvancedContent %s wurde installiert';
$lang['uninstalled'] = 'Modul AdvancedContent %s wurde deinstalliert';
$lang['upgraded'] = 'Modul AdvancedContent auf Version %s aktualisiert. ACHTUNG! Beachten Sie, dass Inhaltsbl&ouml;cke oder Multi-Inputs keine Arrays mehr, sondern Objekte sind. Aktualisieren Sie also ihre Multi-Input-Templates. (Siehe Kommentar beim Bearbeiten von Multi-Input-Templates';
$lang['postinstall'] = 'Modul AdvancedContent %s wurde installiert.';
$lang['postuninstall'] = 'Modul AdvancedContent %s wurde deinstalliert.';
$lang['confirmuninstall'] = '%sWollen Sie das Modul AdvancedContent wirklich deinstallieren?';
$lang['warninguninstall'] = "WARNUNG! Sie haben in den Moduleinstellungen keine Aktion beim Deinstallieren gewählt! Stellen Sie sicher, dass alle Seiten vom Typ 'Erweiterter Inhalt' zurück auf den Standard-Inhaltstypen geändert oder gelöscht werden bevor Sie das Modul entfernen! Anderenfalls funktioniert Ihre CMS Installation nicht mehr! ";
$lang['warninguninstall1'] = "WARNUNG! Damit werden alle Seiten vom Typ 'Erweiterter Inhalt' gelöscht! ";
$lang['warninguninstall2'] = "HINWEIS: Alle Seiten vom Typ 'Erweiterter Inhalt' werden wieder auf den Standard-Inhaltstypen gesetzt! ";
$lang['warninguninstall3'] = "WARNUNG! Alle Seiten vom Typ 'Erweiterter Inhalt' werden wieder auf den Standard-Inhaltstypen gesetzt und alle zusätzichen Inhaltsblöcke werden gelöscht! ";
$lang['notice_duplicatecontent'] = '<em><strong>Hinweis:</strong> Dieser Block wird mehrfach im Template verwendet. Sie sehen hier nur den ersten Block.</em>';
$lang['error_basicattrib'] = "<em><strong>Hinweis:</strong> Der Basis-Inhalts-Eigenschafts-Name '%s' kann nicht als Wert f&uuml;r den Parameter 'block' verwendet werden. <br />Dieser Block ist inaktiv. Nur der erste Block wird angezeigt. Pr&uuml;fen Sie Ihr Seiten-Template und w&auml;hlen Sie f&uuml;r den Parameter 'block' einen anderen Wert.</em>";
$lang['error_expiredate'] = 'Das Enddatum muss hinter dem Startdatum liegen.';
$lang['youareintext'] = 'Aktuelles Verzeichnis';
$lang['dimensions'] = 'Bildgr&ouml;&szlig;e';
$lang['size'] = 'Dateigr&ouml;&szlig;e';
$lang['inherit_from_parent'] = 'Vom &uuml;bergeordneten Element &uuml;bernehmen';
$lang['none'] = 'nichts';
$lang['invalid'] = 'ung&uuml;ltig';
$lang['invalid_block'] = "<em><strong>Hinweis:</strong> Ung&uuml;ltiger Block '%s'.<br />Bitte pr&uuml;fen Sie Ihr Seiten-Template.</em>";
$lang['error_insufficient_blockparams'] = "<em><strong>Fehler:</strong> Unzureichende parameter. <br />Fehlender param '%s' f&uuml;r block '%s'. &Uuml;berpr&uuml;fen Sie Ihr Seiten-Template.</em>";
$lang['yes'] = 'Ja';
$lang['no'] = 'Nein';
$lang['frontendaccess'] = 'Frontend-Zugriff';
$lang['redirectpage'] = 'Seite auf die umgeleitet werden soll, wenn der Zugriff nicht erlaubt ist';
$lang['showloginform'] = 'Anmelde-Formular anzeigen';
$lang['registeredusers'] = 'Nur f&uuml;r registrierte Nutzer';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Ablaufdatum verwenden';
$lang['startdate'] = 'Startdatum';
$lang['enddate'] = 'Enddatum';
$lang['blockcontent'] = 'Block-Inhalt';
$lang['setpageinactive'] = 'Seite auf inaktiv setzen';
$lang['deletepage'] = 'Seite l&ouml;schen';
$lang['uninstallaction'] = 'Aktion beim Deinstallieren';
$lang['setcontent1'] = 'Alle Seiten auf Typ "Inhalt" setzen';
$lang['setcontent2'] = 'Alle Seiten auf Typ "Inhalt" setzen und AdvancedContent-Bl&ouml;cke l&ouml;schen';
$lang['prefsupdated'] = 'Einstellungen aktualisiert';
$lang['success'] = 'OK';
$lang['error'] = 'Fehler';
$lang['deletepages'] = 'Alle Seiten vom Typ "Erweiterter Inhalt" l&ouml;schen';
$lang['importpages'] = "Alle Seiten vom Typ '%s' auf Typ '%s' setzen.";
$lang['confirmimport'] = 'Wollen Sie wirklich den Inhalts-Typ aller Inhaltsseiten &auml;ndern?';
$lang['toggle_message'] = 'Diese Nachricht verbergen';
$lang['contentsettings'] = 'Standard-Einstellungen f&uuml;r den Tab "Erweiterte Optionen"';
$lang['redirectparams'] = 'URL-Parameter, die bei Umleitung angehangen werden sollen';
$lang['evaluatesmarty'] = 'Smarty verwenden, um die Parameter zu verarbeiten';
$lang['error_loading_module'] = "<em><strong>Fehler:</strong> Modul '%s' konnte nicht geladen werden. (angegeben f&uuml;r Block '%s' im Seiten-Template.)</em>";
$lang['error_contentblock_support'] = "<em><strong>Fehler:</strong> Modul '%s' unterst&uuml;tzt keine Inhaltsbl&ouml;cke. (angegeben f&uuml; block '%s' im Seiten-Template.)</em>";
$lang['success_importpages'] = "Alle Seiten des Typs '%s' erfolgreich ge&auml;ndert in '%s'";
$lang['show_advancedcontent_options'] = "Zeige Tab 'Erweiterte Optionen'";
$lang['display_settings'] = '%s Einstellungen anzeigen';
$lang['save_collapse_status'] = 'Speichere Sichtbarkeit von %s';
$lang['content_blocks'] = 'Inhaltsbl&ouml;cke';
$lang['block_message'] = 'Block-Mitteilungen';
$lang['block_groups'] = 'Blockgruppe';
$lang['collapse_default'] = 'Blende %s aus';
$lang['per_page'] = 'pro Seite';
$lang['per_template'] = 'pro Template';
$lang['both1'] = 'Template ODER Seite ';
$lang['both2'] = 'Template UND Seite';
$lang['content'] = 'Inhalt';
$lang['content2'] = 'Erweiterter Inhalt';
$lang['prefs'] = 'Einstellungen';
$lang['multi_input'] = 'Multi Inputs';
$lang['multi_input_tpl'] = 'Multi Input Templates';
$lang['add_multi_input'] = 'Neues multi input hinzug&uuml;gen';
$lang['add_multi_input_tpl'] = 'Neues multi input template hinzuf&uuml;gen';
$lang['input_id'] = 'Eingabe-ID';
$lang['input_fields'] = 'Eingabefelder';
$lang['tpl_name'] = 'Template Name';
$lang['error_template'] = 'Template ist ein Pflichtfeld und darf nicht leer sein ';
$lang['error_input_fields'] = 'Eingabefelder ist ein Pflichtfeld und darf nicht leer sein.';
$lang['error_input_id'] = 'Keine Eingabe-ID angegeben oder Eingabe-ID ist bereits vorhanden.';
$lang['error_input_id_exists'] = 'Eingabe-ID wird bereits verwendet. W&auml;hlen Sie eine andere. (Muss eindeutig sein)';
$lang['multi_input_added'] = 'Multi Input hinzugef&uuml;gt.';
$lang['multi_input_deleted'] = 'Multi Input gel&ouml;scht.';
$lang['multi_input_updated'] = 'Multi Input aktualisiert.';
$lang['multi_input_tpl_added'] = 'Multi Input template hinzugef&uuml;gt.';
$lang['multi_input_tpl_updated'] = 'Multi Input template aktualisiert.';
$lang['multi_input_tpl_deleted'] = 'Multi Input template gel&ouml;scht.';
$lang['delete_selected'] = 'Ausgew&auml;hlte Elemente l&ouml;schen';
$lang['confirm_delete'] = 'Wollen Sie wirklich, dieses Element l&ouml;schen?';
$lang['confirm_delete_selected'] = 'Wollen Sie wirklich, die ausgew&auml;hlten Elemente l&ouml;schen?';
$lang['hide_content'] = 'Keine (nur Inhalt verbergen)';
$lang['hide_menu_item'] = 'Seite im Men&uuml; verbergen';
$lang['loggedout'] = 'wenn ausgeloggt';
$lang['loggedin'] = 'wenn eingeloggt';
$lang['aftercurrdate'] = 'nach dem aktuellen Datum';
$lang['afterstartdate'] = 'nach dem Startdatum';
$lang['minutes'] = 'Minuten';
$lang['hours'] = 'Stunden';
$lang['days'] = 'Tage';
$lang['weeks'] = 'Wochen';
$lang['months'] = 'Monate';
$lang['years'] = 'Jahre';
$lang['switch_params'] = "Die Eigenschaft '%s' aller Seiten auf '%s' setzen";
$lang['feu_params'] = 'Parameter f&uuml;r das FrontEndUsers Modul';
$lang['custom_params'] = 'Benutzerdefinierte URL Parameter, die bei Umleitung angehangen werden sollen';
$lang['confirm_switchparams'] = "Wollen Sie wirklich die Eigenschaft \'%s\' aller Seiten auf die Eigenschaft \'%s\' setzen?";
$lang['success_switchparams'] = "Alle Eigenschaften ge&auml;ndert";
$lang['custom_blocktypes'] = "Benutzerdefinierte Block-Typen";
$lang['plugins'] = "Plugins";
$lang['help_tpl_vars'] = '<p><strong>Template-Variablen:</strong></p>
<p><pre><code>{$inputs}</code></pre> ist ein Array welches alle Input-Elemente des MultiInput Blocks enth&auml;t.<br />
Jedes Input-Element ist wiederum ein Objekt welches alle Parameter enth&auml;lt. <br />
(Siehe Modulhilfe)<br />
Beispiel:</p>
<pre><code>{foreach from=$inputs item=elm}
	{$elm->GetBlockProperty(\'label\')}:&nbsp;{$elm->GetBlockInput()}&nbsp;
{/foreach}</code></pre>';
?>
